==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-config/lxqt-config-input/lxqt-config-input_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>KeyboardConfig</name>
    <message>
        <location filename="../keyboardconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Űrlap</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="20"/>
        <source>Cursor flash time:</source>
        <translation>Kurzos villogási idő:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="27"/>
        <source>&lt;b&gt;Keyboard&lt;/b&gt;</source>
        <translation>&lt;b&gt;Billentyűzet&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="34"/>
        <source>Beep when there is an error of keyboard input</source>
        <translation>Billentyű hibánál csipogás</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="41"/>
        <source> ms</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="51"/>
        <source>Character Repeat</source>
        <translation>Ismétlés</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="79"/>
        <location filename="../keyboardconfig.ui" line="143"/>
        <source>Long</source>
        <translation>Sok</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="108"/>
        <source>Repeat delay:</source>
        <translation>Ismétlési késleltetés:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="115"/>
        <location filename="../keyboardconfig.ui" line="136"/>
        <source>Short</source>
        <translation>Rövid</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="122"/>
        <source>Repeat interval:</source>
        <translation>Ismétlési időköz:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="129"/>
        <source>Type in the following box to test your keyboard settings</source>
        <translation>Írj ide valamit tesztelésre</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="150"/>
        <location filename="../keyboardconfig.ui" line="157"/>
        <source>0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="167"/>
        <source>Turn on NumLock after login</source>
        <translation>Numlok bekapcsolása bejelenkezéskor</translation>
    </message>
</context>
<context>
    <name>KeyboardLayoutConfig</name>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="20"/>
        <source>&lt;b&gt;Keyboard Layout&lt;/b&gt;</source>
        <translation>&lt;b&gt;Billentyűkiosztás&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="48"/>
        <source>Layout</source>
        <translation>Kiosztás</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="53"/>
        <source>Variant</source>
        <translation>Változat</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="63"/>
        <source>&amp;Add</source>
        <translation>Hozzá&amp;ad</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="70"/>
        <source>&amp;Remove</source>
        <translation>Tö&amp;röl</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="77"/>
        <source>up</source>
        <translation>föl</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="84"/>
        <source>down</source>
        <translation>le</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="108"/>
        <source>Keyboard model:</source>
        <translation>Billentyűzet modell:</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="122"/>
        <source>Keys to change layout:</source>
        <translation>Kiosztásváltoztató billentyű:</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="133"/>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="141"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note&lt;/span&gt;: If you are using an &lt;span style=&quot; font-weight:600;&quot;&gt;input method&lt;/span&gt;, such as IBus, uim, fcitx, or gcin, the settings here &lt;span style=&quot; font-weight:600;&quot;&gt;might not work&lt;/span&gt; because they are overridden by the input methods.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Megjegyzés&lt;/span&gt;: Ha bevitelként &lt;span style=&quot; font-weight:600;&quot;&gt;például&lt;/span&gt;, IBus, uim, fcitx, or gcin, szolgálnakl, ezek a beállítások &lt;span style=&quot; font-weight:600;&quot;&gt;nem működnek&lt;/span&gt; mert azok a beviteli módok ezt felülírják.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>MouseConfig</name>
    <message>
        <location filename="../mouseconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Űrlap</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="23"/>
        <source>&lt;b&gt;Mouse&lt;/b&gt;</source>
        <translation>&lt;b&gt;Egér&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="30"/>
        <source>Motion</source>
        <translation>Mozgás</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="36"/>
        <source>High</source>
        <translation>Nagy</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="43"/>
        <source>Fast</source>
        <translation>Gyors</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="50"/>
        <source>Sensitivity:</source>
        <translation>Érzékenység:</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="57"/>
        <source>Low</source>
        <translation>Kicsi</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="83"/>
        <source>Acceleration:</source>
        <translation>Gyorsulás:</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="109"/>
        <source>Slow</source>
        <translation>Lassú</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="116"/>
        <location filename="../mouseconfig.ui" line="123"/>
        <source>0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="133"/>
        <source>Double click interval:</source>
        <translation>Duplakattintás:</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="140"/>
        <source> ms</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="150"/>
        <source>Wheel scroll lines:</source>
        <translation>Gördítő sorok:</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="160"/>
        <source>Left handed (Swap left and right mouse buttons)</source>
        <translation>Balkezes (Bal és jobb gombok cseréje)</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="167"/>
        <source>Single click to activate items</source>
        <translation>Egykattintásos aktiválás</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../lxqt-config-input.cpp" line="34"/>
        <source>Keyboard and Mouse Settings</source>
        <translation>Billentyű és egérbeállítás</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="39"/>
        <source>Mouse</source>
        <translation>Egér</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="44"/>
        <source>Cursor</source>
        <translation>Kurzor</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="47"/>
        <source>Keyboard</source>
        <translation>Billentyűzet</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="51"/>
        <source>Keyboard Layout</source>
        <translation>Billentyűkiosztás</translation>
    </message>
</context>
<context>
    <name>SelectKeyboardLayoutDialog</name>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="14"/>
        <source>Select a keyboard layout</source>
        <translation>Billentyűzetkiosztás választása</translation>
    </message>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="20"/>
        <source>Keyboard layout</source>
        <translation>Billentyűkiosztás</translation>
    </message>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="27"/>
        <source>Variant</source>
        <translation>Változat</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-config/lxqt-config-input/lxqt-config-input_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>KeyboardConfig</name>
    <message>
        <location filename="../../../keyboardconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Űrlap</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="20"/>
        <source>Cursor flash time:</source>
        <translation>Kurzos villogási idő:</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="27"/>
        <source>&lt;b&gt;Keyboard&lt;/b&gt;</source>
        <translation>&lt;b&gt;Billentyűzet&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="34"/>
        <source>Beep when there is an error of keyboard input</source>
        <translation>Billentyű hibánál csipogás</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="41"/>
        <source> ms</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="51"/>
        <source>Character Repeat</source>
        <translation>Ismétlés</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="79"/>
        <location filename="../../../keyboardconfig.ui" line="143"/>
        <source>Long</source>
        <translation>Sok</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="108"/>
        <source>Repeat delay:</source>
        <translation>Ismétlési késleltetés:</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="115"/>
        <location filename="../../../keyboardconfig.ui" line="136"/>
        <source>Short</source>
        <translation>Rövid</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="122"/>
        <source>Repeat interval:</source>
        <translation>Ismétlési időköz:</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="129"/>
        <source>Type in the following box to test your keyboard settings</source>
        <translation>Írj ide valamit tesztelésre</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="150"/>
        <location filename="../../../keyboardconfig.ui" line="157"/>
        <source>0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="167"/>
        <source>Turn on NumLock after login</source>
        <translation>Numlok bekapcsolása bejelenkezéskor</translation>
    </message>
</context>
<context>
    <name>KeyboardLayoutConfig</name>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="20"/>
        <source>&lt;b&gt;Keyboard Layout&lt;/b&gt;</source>
        <translation>&lt;b&gt;Billentyűkiosztás&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="48"/>
        <source>Layout</source>
        <translation>Kiosztás</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="53"/>
        <source>Variant</source>
        <translation>Változat</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="63"/>
        <source>&amp;Add</source>
        <translation>Hozzá&amp;ad</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="70"/>
        <source>&amp;Remove</source>
        <translation>Tö&amp;röl</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="77"/>
        <source>up</source>
        <translation>föl</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="84"/>
        <source>down</source>
        <translation>le</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="108"/>
        <source>Keyboard model:</source>
        <translation>Billentyűzet modell:</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="122"/>
        <source>Keys to change layout:</source>
        <translation>Kiosztásváltoztató billentyű:</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="133"/>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="141"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note&lt;/span&gt;: If you are using an &lt;span style=&quot; font-weight:600;&quot;&gt;input method&lt;/span&gt;, such as IBus, uim, fcitx, or gcin, the settings here &lt;span style=&quot; font-weight:600;&quot;&gt;might not work&lt;/span&gt; because they are overridden by the input methods.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Megjegyzés&lt;/span&gt;: Ha bevitelként &lt;span style=&quot; font-weight:600;&quot;&gt;például&lt;/span&gt;, IBus, uim, fcitx, or gcin, szolgálnakl, ezek a beállítások &lt;span style=&quot; font-weight:600;&quot;&gt;nem működnek&lt;/span&gt; mert azok a beviteli módok ezt felülírják.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>MouseConfig</name>
    <message>
        <location filename="../../../mouseconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Űrlap</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="23"/>
        <source>&lt;b&gt;Mouse&lt;/b&gt;</source>
        <translation>&lt;b&gt;Egér&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="30"/>
        <source>Motion</source>
        <translation>Mozgás</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="36"/>
        <source>High</source>
        <translation>Nagy</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="43"/>
        <source>Fast</source>
        <translation>Gyors</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="50"/>
        <source>Sensitivity:</source>
        <translation>Érzékenység:</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="57"/>
        <source>Low</source>
        <translation>Kicsi</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="83"/>
        <source>Acceleration:</source>
        <translation>Gyorsulás:</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="109"/>
        <source>Slow</source>
        <translation>Lassú</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="116"/>
        <location filename="../../../mouseconfig.ui" line="123"/>
        <source>0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="133"/>
        <source>Double click interval:</source>
        <translation>Duplakattintás:</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="140"/>
        <source> ms</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="150"/>
        <source>Wheel scroll lines:</source>
        <translation>Gördítő sorok:</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="160"/>
        <source>Left handed (Swap left and right mouse buttons)</source>
        <translation>Balkezes (Bal és jobb gombok cseréje)</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="167"/>
        <source>Single click to activate items</source>
        <translation>Egykattintásos aktiválás</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="34"/>
        <source>Keyboard and Mouse Settings</source>
        <translation>Billentyű és egérbeállítás</translation>
    </message>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="39"/>
        <source>Mouse</source>
        <translation>Egér</translation>
    </message>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="44"/>
        <source>Cursor</source>
        <translation>Kurzor</translation>
    </message>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="47"/>
        <source>Keyboard</source>
        <translation>Billentyűzet</translation>
    </message>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="51"/>
        <source>Keyboard Layout</source>
        <translation>Billentyűkiosztás</translation>
    </message>
</context>
<context>
    <name>SelectKeyboardLayoutDialog</name>
    <message>
        <location filename="../../../selectkeyboardlayoutdialog.ui" line="14"/>
        <source>Select a keyboard layout</source>
        <translation>Billentyűzetkiosztás választása</translation>
    </message>
    <message>
        <location filename="../../../selectkeyboardlayoutdialog.ui" line="20"/>
        <source>Keyboard layout</source>
        <translation>Billentyűkiosztás</translation>
    </message>
    <message>
        <location filename="../../../selectkeyboardlayoutdialog.ui" line="27"/>
        <source>Variant</source>
        <translation>Változat</translation>
    </message>
</context>
</TS>
